==> leo-sdk-oracle-1.0.0-sources.jar: io/leoplatform/sdk/oracle/SimpleOracleChangeSource.java <==
package io.leoplatform.sdk.oracle;

import oracle.jdbc.OracleConnection;

import java.sql.SQLException;
import java.util.*;

import static java.util.stream.Collectors.toList;

public final class SimpleOracleChangeSource implements OracleChangeSource {

    private final OracleConnection conn;
    private final List<String> tables;

    public SimpleOracleChangeSource(OracleConnection conn, Collection<String> tables) {
        this.conn = Optional.ofNullable(conn)
                .filter(this::pingable)
                .orElseThrow(() -> new IllegalStateException("Missing or invalid connection"));
        this.tables = validate(tables);
    }

    private List<String> validate(Collection<String> tables) {
        List<String> tbls = Optional.ofNullable(tables)
                .orElse(Collections.emptyList())
                .stream()
                .filter(Objects::nonNull)
                .map(String::trim)
                .filter(t -> !t.isEmpty())
                .collect(toList());
        return Optional.of(tbls)
                .filter(t -> !t.isEmpty())
                .orElseThrow(() -> new IllegalArgumentException("Must watch one or more tables"));
    }

    private boolean pingable(OracleConnection c) {
        try {
            return c.pingDatabase() == OracleConnection.DATABASE_OK;
        } catch (SQLException e) {
            throw new IllegalStateException("Cannot ping database", e);
        }
    }

    @Override
    public OracleConnection connection() {
        return conn;
    }

    @Override
    public List<String> tables() {
        return tables;
    }
}

==> leo-sdk-oracle-1.0.10-sources.jar: io/leoplatform/sdk/oracle/SimpleOracleChangeSource.java <==
package io.leoplatform.sdk.oracle;

import oracle.jdbc.OracleConnection;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.SQLException;
import java.util.*;

import static java.util.stream.Collectors.toList;

public final class SimpleOracleChangeSource implements OracleChangeSource {
    private static final Logger log = LoggerFactory.getLogger(SimpleOracleChangeSource.class);

    private final OracleConnection conn;
    private final List<String> tables;

    public SimpleOracleChangeSource(OracleConnection conn, Collection<String> tables) {
        this.conn = Optional.ofNullable(conn)
                .filter(this::pingable)
                .orElseThrow(() -> new IllegalStateException("Missing or invalid connection"));
        this.tables = validate(tables);
    }

    private List<String> validate(Collection<String> tables) {
        List<String> tbls = Optional.ofNullable(tables)
                .orElse(Collections.emptyList())
                .stream()
                .filter(Objects::nonNull)
                .map(String::trim)
                .filter(t -> !t.isEmpty())
                .collect(toList());
        return Optional.of(tbls)
                .filter(t -> !t.isEmpty())
                .orElseThrow(() -> new IllegalArgumentException("Must watch one or more tables"));
    }

    private boolean pingable(OracleConnection c) {
        try {
            return c.pingDatabase() == OracleConnection.DATABASE_OK;
        } catch (SQLException e) {
            throw new IllegalStateException("Cannot ping database", e);
        }
    }

    @Override
    public OracleConnection connection() {
        return conn;
    }

    @Override
    public List<String> tables() {
        return tables;
    }

    @Override
    public void end() {
        try {
            conn.close();
        } catch (SQLException e) {
            log.warn("Could not close connection", e);
        }
    }
}
